@@ -4,7 +4,11 @@ import click
 from pprint import pprint
 from docarray import DocumentArray, Document
 from jina import Client
-from jfc.helper import Formats
+
+try:
+    from jfc.helper import Formats # if running Python package directly
+except:
+    from helper import Formats # if running via `python jfc ...`
 
 def index(host, num_docs, data, tags, **kwargs):
     """
@@ -94,22 +98,29 @@ def search(data, host, tags, **kwargs):
             pprint(match.tags)
         print("-" * 60)
 
+def other_endpoint(endpoint, host):
+    client = Client(host=host)
+    response = client.post(on=f"/{endpoint}")
+
+    for doc in response:
+        print(doc.tags)
+
 
 
 @click.command()
 @click.argument("task")
-@click.argument("data")
+@click.argument("data", required=False)
 @click.option("--num_docs", "-n")
 @click.option("--host", "-h")
 @click.option("--tags", is_flag=True)
 # @click.option("--config_file", "-c")
 def main(task: str, host, num_docs, data, tags):
     if task == "index":
-        index(host=host, num_docs=num_docs, data=data, tags=None)
+        index(data, host=host, num_docs=num_docs, tags=None)
     elif task == "search":
         search(data, host=host, num_docs=num_docs, tags=tags)
     else:
-        print("Please add 'index' or 'search' to your command")
+        other_endpoint(endpoint=task, host=host)
 
 
 if __name__ == "__main__":
